@@ -57,9 +57,9 @@ class HtmlAttr(dict, UnicodeMixin):
 
         if value.endswith('|angular'):
             value = value[:-8]
-            string = '"{{{{{{{{\'{}\'|angular}}}}}}}}"'
+            string = '"{{{{{{{{{}}}}}}}}}"'
 
-        return string.format(value.replace('\'', '\\\''))
+        return string.format(value)
 
     @staticmethod
     def _to_attr(key, value):
@@ -288,8 +288,8 @@ class Widget(object):
                 if not args:
                     customize(self)
                 else:
-                    local_kwargs = dict({(k, v) for k, v in kwargs.iteritems()
-                                                if k in args})
+                    local_kwargs = dict((k, v) for k, v in kwargs.iteritems()
+                                                if k in args)
                     customize(self, **local_kwargs)
         # start the recursion
         if self.__class__ is not Widget:
